# masonite-api-pagination
Simple API pagination to Masonite API package with Orator

- [X] Document the basic response
- [X] Return total rows
- [X] Return next/previous route
- [ ] Allow filter/search
- [ ] Allow order by
